from distutils.core import setup
setup(
	name='Tnester2',
	version='1.1.0',
	py_modules=['Tnester2'],
	author='echo',
	author_email='2026336228@qq.com',
	url='http://www.headfirstlabs.com',
	description='A simple printer of nested lists',
	)
